# ****Cliby****
### C libaries in python simplified
### Compile your C files to be accessible with one command
## Just run ```makelib``` in cmd to compile your files, and define input and output
```
makelib <C source file> <Your desired output directory>
```
### Then, just import the generated library with python's built-in in ctypes
```
```